RepoViewField

Enum RepoViewField 

pub enum RepoViewField {
    NameWithOwner,
    Url,
}
Repository fields available for querying via gh repo view.

Variants



NameWithOwner



Url

Implementations

Source

impl RepoViewField

pub fn jq_repr(&self) -> String

Returns the jq representation of the field for GitHub CLI queries.